<?php

/**
 * @file
 * Vieww handlers for iToggle
 */

/**
 * A handler to provide a custom field
 *
 * @ingroup views_field_handlers
 */
abstract class itoggle_handler extends views_handler_field {

  protected static $itoggle_init = FALSE;
  
  // I have found no place to add css/js includes that executes just once per view
  // all functions here will be executed once per itoggle field
  // we use a static cache to avoid this
  function init(&$view, &$options) {
    if (self::$itoggle_init === FALSE) {
      self::$itoggle_init = TRUE;
      itoggle_include_itoggle();
      drupal_add_js(array(
        'itoggle' => array(
          'easing' => variable_get_value('itoggle_easing'),
          'speed' => variable_get_value('itoggle_speed'),
          'onclick' => variable_get_value('itoggle_onclick'),
          'onclickon' => variable_get_value('itoggle_onclickon'),
          'onclickoff' => variable_get_value('itoggle_onclickoff'),
          'onslide' => variable_get_value('itoggle_onslide'),
          'onslideon' => variable_get_value('itoggle_onslideon'),
          'onslideoff' => variable_get_value('itoggle_onslideoff'),
        )
      ), 'setting');
      drupal_add_js(drupal_get_path('module', 'itoggle') . '/js/itoggle.js');
    }
    parent::init($view, $options);
  }

  function query() {
    // Do nothing, as this handler does not need to do anything to the query itself.
  }

  /**
   * Return markup for itoggle checkbox
   * 
   * @param mixed $id
   * @param string $type
   * @param bool $checked
   * @return string
   */
  protected function _itoggle_render($id, $type, $checked) {
    $checked = ($checked === TRUE) ? 'checked="checked"' : '';
    $element_id = "itoggle_{$type}_{$id}";

    return <<<HTML
<div class="itoggle-wrapper" data-id="{$id}" data-type="{$type}">
  <input type="checkbox" id="{$element_id}" {$checked} />
</div>
HTML;
  }

}

/**
 * A handler to provide a custom iToggle Node Status field
 *
 * @ingroup views_field_handlers
 */
class itoggle_handler_field_node_status extends itoggle_handler {

  /**
   * Render the trigger field and its linked popup information.
   */
  function render($values) {
    if (isset($values->nid)) {
      if (!isset($values->node_status)) {
        $node = node_load($values->nid);
        $values->node_status = $node->status;
      }

      $type = 'node_status';
      $id = $values->nid;
      $checked = $values->node_status == 1;
      return $this->_itoggle_render($id, $type, $checked);
    }
    return NULL;
  }

  /**
   * Get this field's label.
   */
  function label() {
    if (!isset($this->options['label'])) {
      return t('Status');
    }
    return $this->options['label'];
  }
  
}

/**
 * A handler to provide a custom iToggle Node Promote field
 *
 * @ingroup views_field_handlers
 */
class itoggle_handler_field_node_promote extends itoggle_handler {

  /**
   * Render the trigger field and its linked popup information.
   */
  function render($values) {
    if (isset($values->nid)) {
      if (!isset($values->node_promote)) {
        $node = node_load($values->nid);
        $values->node_promote = $node->promote;
      }

      $type = 'node_promote';
      $id = $values->nid;
      $checked = $values->node_promote == 1;
      return $this->_itoggle_render($id, $type, $checked);
    }
    return NULL;
  }

  /**
   * Get this field's label.
   */
  function label() {
    if (!isset($this->options['label'])) {
      return t('Promoted');
    }
    return $this->options['label'];
  }
}

/**
 * A handler to provide a custom iToggle Node Sticky field
 *
 * @ingroup views_field_handlers
 */
class itoggle_handler_field_node_sticky extends itoggle_handler {

  /**
   * Render the trigger field and its linked popup information.
   */
  function render($values) {
    if (isset($values->nid)) {
      if (!isset($values->node_sticky)) {
        $node = node_load($values->nid);
        $values->node_sticky = $node->sticky;
      }

      $type = 'node_sticky';
      $id = $values->nid;
      $checked = $values->node_sticky == 1;
      return $this->_itoggle_render($id, $type, $checked);
    }
    return NULL;
  }

  /**
   * Get this field's label.
   */
  function label() {
    if (!isset($this->options['label'])) {
      return t('Sticky');
    }
    return $this->options['label'];
  }
}

/**
 * A handler to provide a custom iToggle User Status field
 *
 * @ingroup views_field_handlers
 */
class itoggle_handler_field_user_status extends itoggle_handler {

  /**
   * Render the trigger field and its linked popup information.
   */
  function render($values) {
    if (isset($values->uid)) {
      if (!isset($values->users_status)) {
        $user = user_load($values->uid);
        $values->users_status = $user->status;
      }

      $type = 'user_status';
      $id = $values->uid;
      $checked = $values->users_status == 1;
      return $this->_itoggle_render($id, $type, $checked);
    }
    return NULL;
  }

  /**
   * Get this field's label.
   */
  function label() {
    if (!isset($this->options['label'])) {
      return t('Status');
    }
    return $this->options['label'];
  }
}